@@ -1,6 +1,6 @@
 //!# Interface
 //!
-//!The method [Database]::run (or alternatively Database::run_timed) is called to execute an SQL query.
+//!The method [Database::run] (or alternatively [Database::run_timed]) is called to execute an SQL query.
 //!This takes a [Transaction] parameter which accumulates SELECT results and which also has methods
 //!for accessing the environment and controlling output. Custom builtin functions implement [CExp] and have access to the query
 //!via an [EvalEnv] parameter, which can be downcast if necessary.   
@@ -50,7 +50,7 @@
 //! SortedFile stores fixed size Records in a tree of Pages.
 //! SortedFile is used to implement:
 //!
-//! - Variable length values ( which are split into fragments - see bytes module - although up to 15 bytes can be stored directly. ).
+//! - Variable length values which are split into fragments - see bytes module - although up to 254 bytes can be stored inline.
 //!
 //! - Database Table storage. Each record has a 64-bit Id.
 //!
@@ -62,23 +62,21 @@
 //!
 //! [SharedPagedData] allows logical database pages to be shared to allow concurrent readers.
 //!
+//! [AtomicFile] ensures that database updates are all or nothing.
+//!
 //!# ToDo List
+//! Decide whether to have several crates : "Core", "Lang", "Server" say.
+//! Core being data storage, Lang being SQL-subset, Server being interfacing to http/serde etc.
 //!
-//! Implement string(n), binary(n) where n is number of bytes stored inline. (DONE)
+//! Unify GenTransaction and WebTransaction. Check multiple file upload works ok with local http parsing.
 //!
-//! Also simplify tinyint, smallint, int, INT to int(1), int(2), int(4), int(8) = default. (MOSTLY DONE)
+//! Implement DROP INDEX, ALTER TABLE, fully implement CREATE INDEX.
 //!
-//! Unify GenTransaction and WebTransaction.
+//! Implement email in example program. Replication of log files. Server status.
 //!
-//!Implement DROP INDEX, ALTER TABLE, fully implement CREATE INDEX.
+//! Sort out error handling for PARSEINT etc.
 //!
-//!Consider replication/backup/durability issues [Here](https://en.wikipedia.org/wiki/Durability_(database_systems))
-//!
-//!Implement email in example program. Replication of log files. Server status.
-//!
-//!Sort out error handling for PARSEINT etc.
-//!
-//!Work on improving/testing SQL code, browse schema, float I/O. Login.
+//! Work on improving/testing SQL code, browse schema, float I/O. Login.
 //!
 
 pub use crate::{
@@ -228,7 +226,7 @@ pub mod run;
 mod run;
 
 #[cfg(feature = "max")]
-/// Sorted [Record] storage.
+/// [SortedFile] : [Record] storage.
 pub mod sortedfile;
 #[cfg(not(feature = "max"))]
 mod sortedfile;
@@ -303,8 +301,6 @@ impl Database {
                 ("Root", INT),
                 ("Schema", INT),
                 ("Name", STRING),
-                ("IsView", INT1),
-                ("Def", STRING),
                 ("IdGen", INT),
             ],
         );
@@ -355,7 +351,7 @@ impl Database {
 CREATE SCHEMA sys
 GO
 CREATE TABLE sys.Schema( Name string )
-CREATE TABLE sys.Table( Root int, Schema int, Name string, IsView int(1), Def string, IdGen int )
+CREATE TABLE sys.Table( Root int, Schema int, Name string, IdGen int )
 CREATE TABLE sys.Column( Table int, Name string, Type int )
 CREATE TABLE sys.Index( Root int, Table int, Name string )
 CREATE TABLE sys.IndexColumn( Index int, ColId int )
@@ -398,8 +394,9 @@ GO
             start.elapsed().as_micros()
         );
     }
+
     /// Run a batch of SQL.
-    pub fn go(self: &DB, source: &str, tr: &mut dyn Transaction) -> Option<SqlError> {
+    pub(crate) fn go(self: &DB, source: &str, tr: &mut dyn Transaction) -> Option<SqlError> {
         let mut p = Parser::new(source, self);
         let result = std::panic::catch_unwind(panic::AssertUnwindSafe(|| {
             p.batch(tr);
@@ -459,7 +456,7 @@ GO
     }
 
     /// Get the named table.
-    pub fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
+    pub(crate) fn get_table(self: &DB, name: &ObjRef) -> Option<TablePtr> {
         if let Some(t) = self.tables.borrow().get(name) {
             return Some(t.clone());
         }
@@ -467,7 +464,7 @@ GO
     }
 
     /// Get the named function.
-    pub fn get_function(self: &DB, name: &ObjRef) -> Option<FunctionPtr> {
+    pub(crate) fn get_function(self: &DB, name: &ObjRef) -> Option<FunctionPtr> {
         if let Some(f) = self.functions.borrow().get(name) {
             return Some(f.clone());
         }
@@ -475,13 +472,13 @@ GO
     }
 
     /// Insert the table into the map of tables.
-    pub fn publish_table(&self, table: TablePtr) {
+    pub(crate) fn publish_table(&self, table: TablePtr) {
         let name = table.info.name.clone();
         self.tables.borrow_mut().insert(name, table);
     }
 
     /// Get code for value.
-    pub fn encode(self: &DB, val: &Value, size: usize) -> u64 {
+    pub(crate) fn encode(self: &DB, val: &Value, size: usize) -> u64 {
         let bytes = match val {
             Value::RcBinary(x) => &**x,
             Value::ArcBinary(x) => &**x,
@@ -497,22 +494,22 @@ GO
     }
 
     /// Decode u64 to bytes.
-    pub fn decode(self: &DB, code: u64, inline: usize) -> Vec<u8> {
+    pub(crate) fn decode(self: &DB, code: u64, inline: usize) -> Vec<u8> {
         self.bs.decode(self, code, inline)
     }
 
     /// Delete encoding.
-    pub fn delcode(self: &DB, code: u64) {
+    pub(crate) fn delcode(self: &DB, code: u64) {
         self.bs.delcode(self, code);
     }
 
     /// Allocate a page of underlying file storage.
-    pub fn alloc_page(self: &DB) -> u64 {
+    pub(crate) fn alloc_page(self: &DB) -> u64 {
         self.file.alloc_page()
     }
 
     /// Free a page of underyling file storage.
-    pub fn free_page(self: &DB, lpnum: u64) {
+    pub(crate) fn free_page(self: &DB, lpnum: u64) {
         self.file.free_page(lpnum);
     }
 } // end impl Database
